==> heptapod-rails-0.19.1.tar.gz: heptapod-rails-0.19.1/spec/frontend/pipelines/pipeline_graph/mock_data.js <==
import { createUniqueLinkId } from '~/pipelines/utils';

export const yamlString = `stages:
- empty
- build
- test
- deploy
- final

include:
- template: 'Workflows/MergeRequest-Pipelines.gitlab-ci.yml'

build_a:
  stage: build
  script: echo hello
build_b:
  stage: build
  script: echo hello
build_c:
  stage: build
  script: echo hello
build_d:
  stage: Queen
  script: echo hello

test_a:
  stage: test
  script: ls
  needs: [build_a, build_b, build_c]
test_b:
  stage: test
  script: ls
  needs: [build_a, build_b, build_d]
test_c:
  stage: test
  script: ls
  needs: [build_a, build_b, build_c]

deploy_a:
  stage: deploy
  script: echo hello
`;

const jobId1 = createUniqueLinkId('build', 'build_1');
const jobId2 = createUniqueLinkId('test', 'test_1');
const jobId3 = createUniqueLinkId('test', 'test_2');
const jobId4 = createUniqueLinkId('deploy', 'deploy_1');

export const pipelineData = {
  stages: [
    {
      name: 'build',
      groups: [
        {
          name: 'build_1',
          jobs: [{ script: 'echo hello', stage: 'build' }],
          id: jobId1,
        },
      ],
    },
    {
      name: 'test',
      groups: [
        {
          name: 'test_1',
          jobs: [{ script: 'yarn test', stage: 'test' }],
          id: jobId2,
        },
        {
          name: 'test_2',
          jobs: [{ script: 'yarn karma', stage: 'test' }],
          id: jobId3,
        },
      ],
    },
    {
      name: 'deploy',
      groups: [
        {
          name: 'deploy_1',
          jobs: [{ script: 'yarn magick', stage: 'deploy' }],
          id: jobId4,
        },
      ],
    },
  ],
  jobs: {
    [jobId1]: {},
    [jobId2]: {},
    [jobId3]: {},
    [jobId4]: {},
  },
};

export const singleStageData = {
  stages: [
    {
      name: 'build',
      groups: [
        {
          name: 'build_1',
          jobs: [{ script: 'echo hello', stage: 'build' }],
          id: jobId1,
        },
      ],
    },
  ],
};

==> heptapod-rails-0.21.3.tar.gz: heptapod-rails-0.21.3/spec/frontend/pipelines/pipeline_graph/mock_data.js <==
export const yamlString = `stages:
- empty
- build
- test
- deploy
- final

include:
- template: 'Workflows/MergeRequest-Pipelines.gitlab-ci.yml'

build_a:
  stage: build
  script: echo hello
build_b:
  stage: build
  script: echo hello
build_c:
  stage: build
  script: echo hello
build_d:
  stage: Queen
  script: echo hello

test_a:
  stage: test
  script: ls
  needs: [build_a, build_b, build_c]
test_b:
  stage: test
  script: ls
  needs: [build_a, build_b, build_d]
test_c:
  stage: test
  script: ls
  needs: [build_a, build_b, build_c]

deploy_a:
  stage: deploy
  script: echo hello
`;

export const pipelineDataWithNoNeeds = {
  stages: [
    {
      name: 'build',
      groups: [
        {
          name: 'build_1',
          jobs: [{ script: 'echo hello', stage: 'build' }],
        },
      ],
    },
    {
      name: 'test',
      groups: [
        {
          name: 'test_1',
          jobs: [{ script: 'yarn test', stage: 'test' }],
        },
      ],
    },
  ],
};

export const pipelineData = {
  stages: [
    {
      name: 'build',
      groups: [
        {
          name: 'build_1',
          jobs: [{ script: 'echo hello', stage: 'build' }],
        },
      ],
    },
    {
      name: 'test',
      groups: [
        {
          name: 'test_1',
          jobs: [{ script: 'yarn test', stage: 'test' }],
        },
        {
          name: 'test_2',
          jobs: [{ script: 'yarn karma', stage: 'test' }],
        },
      ],
    },
    {
      name: 'deploy',
      groups: [
        {
          name: 'deploy_1',
          jobs: [{ script: 'yarn magick', stage: 'deploy', needs: ['test_1'] }],
        },
      ],
    },
  ],
};

export const parallelNeedData = {
  stages: [
    {
      name: 'build',
      groups: [
        {
          name: 'build_1',
          parallel: 3,
          jobs: [
            { script: 'echo hello', stage: 'build', name: 'build_1 1/3' },
            { script: 'echo hello', stage: 'build', name: 'build_1 2/3' },
            { script: 'echo hello', stage: 'build', name: 'build_1 3/3' },
          ],
        },
      ],
    },
    {
      name: 'test',
      groups: [
        {
          name: 'test_1',
          jobs: [{ script: 'yarn test', stage: 'test', needs: ['build_1'] }],
        },
      ],
    },
  ],
};

export const largePipelineData = {
  stages: [
    {
      name: 'build',
      groups: [
        {
          name: 'build_1',
          jobs: [{ script: 'echo hello', stage: 'build' }],
        },
        {
          name: 'build_2',
          jobs: [{ script: 'echo hello', stage: 'build' }],
        },
        {
          name: 'build_3',
          jobs: [{ script: 'echo hello', stage: 'build' }],
        },
      ],
    },
    {
      name: 'test',
      groups: [
        {
          name: 'test_1',
          jobs: [{ script: 'yarn test', stage: 'test', needs: ['build_2'] }],
        },
        {
          name: 'test_2',
          jobs: [{ script: 'yarn karma', stage: 'test', needs: ['build_2'] }],
        },
      ],
    },
    {
      name: 'deploy',
      groups: [
        {
          name: 'deploy_1',
          jobs: [{ script: 'yarn magick', stage: 'deploy', needs: ['test_1'] }],
        },
        {
          name: 'deploy_2',
          jobs: [{ script: 'yarn magick', stage: 'deploy', needs: ['build_3'] }],
        },
        {
          name: 'deploy_3',
          jobs: [{ script: 'yarn magick', stage: 'deploy', needs: ['test_2'] }],
        },
      ],
    },
  ],
};

export const singleStageData = {
  stages: [
    {
      name: 'build',
      groups: [
        {
          name: 'build_1',
          jobs: [{ script: 'echo hello', stage: 'build' }],
        },
      ],
    },
  ],
};

export const rootRect = {
  bottom: 463,
  height: 271,
  left: 236,
  right: 1252,
  top: 192,
  width: 1016,
  x: 236,
  y: 192,
};

export const jobRect = {
  bottom: 312,
  height: 24,
  left: 308,
  right: 428,
  top: 288,
  width: 120,
  x: 308,
  y: 288,
};
